.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :end-before: ---

.. toctree::
   :caption: Sections
   :maxdepth: 3
   :hidden:

   api
   developer_guide
   changelog

.. toctree::
   :caption: Links
   :hidden:

   GitHub <https://github.com/int-brain-lab/bpod-modules-ibl/>
   PyPI <https://pypi.org/project/bpod-modules-ibl/>
